@@ -1,3 +1,3 @@
-from .spl_packet_utils import SplPacketUtils
+from .spl_packet_utils import *
 from .spl_streaming_batch_command import *
 from .spl_streaming_chunk_command import *
